pub struct Equippable {
pub slot: EquippableSlot,
}Expand description
The equippable component data.
Fields
slot: EquippableSlotTrait Implementations
Sourceimpl Clone for Equippable
impl Clone for Equippable
Sourcefn clone(&self) -> Equippable
fn clone(&self) -> Equippable
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Component for Equippable
impl Component for Equippable
Sourcefn into_data(self) -> ComponentData
fn into_data(self) -> ComponentData
Converts this component value into
ComponentData.Sourcefn from_data(data: ComponentData) -> Option<Self>
fn from_data(data: ComponentData) -> Option<Self>
Attempts to extract this component type from
ComponentData.
Returns None if the data is a different variant.Sourcefn from_data_ref(data: &ComponentData) -> Option<&Self>
fn from_data_ref(data: &ComponentData) -> Option<&Self>
Attempts to get a reference to this component type from
ComponentData.
Returns None if the data is a different variant or if the type
cannot be referenced directly (e.g., needs conversion).Sourceimpl Debug for Equippable
impl Debug for Equippable
Sourceimpl FromNbtTag for Equippable
impl FromNbtTag for Equippable
fn from_nbt_tag(tag: NbtTag<'_, '_>) -> Option<Self>
fn from_optional_nbt_tag( tag: Option<NbtTag<'_, '_>>, ) -> Result<Option<Self>, DeserializeError>
Sourceimpl HashComponent for Equippable
impl HashComponent for Equippable
Sourcefn hash_component(&self, hasher: &mut ComponentHasher)
fn hash_component(&self, hasher: &mut ComponentHasher)
Hashes this value into the given hasher.
Sourcefn compute_hash(&self) -> i32
fn compute_hash(&self) -> i32
Computes the hash of this value.
Sourceimpl PartialEq for Equippable
impl PartialEq for Equippable
Sourcefn eq(&self, other: &Equippable) -> bool
fn eq(&self, other: &Equippable) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ReadFrom for Equippable
impl ReadFrom for Equippable
impl StructuralPartialEq for Equippable
Sourceimpl ToNbtTag for Equippable
impl ToNbtTag for Equippable
fn to_nbt_tag(self) -> NbtTag
fn to_optional_nbt_tag(self) -> Option<NbtTag>